==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/General/kdenotify/translations/kdenotify_plugin_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu">
<context>
    <name>KdeNotify</name>
    <message>
        <location filename="../kdenotify.cpp" line="122"/>
        <source>Qmmp now playing:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KdeNotifyFactory</name>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="30"/>
        <source>KDE notification plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="50"/>
        <source>About KDE Notification Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="51"/>
        <source>KDE notification plugin for Qmmp</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>KDE 4 Notification Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Notification delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Update visible notification instead create new</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Show covers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Edit template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="75"/>
        <source>Notification Template</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/General/kdenotify/translations/kdenotify_plugin_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu_HU">
<context>
    <name>KdeNotify</name>
    <message>
        <location filename="../kdenotify.cpp" line="121"/>
        <source>Qmmp now playing:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KdeNotifyFactory</name>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="31"/>
        <source>KDE 4 notification plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="51"/>
        <source>About KDE Notification Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../kdenotifyfactory.cpp" line="52"/>
        <source>KDE 4 notification plugin for Qmmp 
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>KDE 4 Notification Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Notification delay [s]:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>Update visible notification instead create new</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Show covers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Edit template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="75"/>
        <source>Notification Template</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
